@@ -4,6 +4,8 @@ from metacatalog.db.session import (
     load_connection
 )
 
+from ._util import cprint
+
 def connection(args):
     # check if the save flag is given
     if args.save is not None:
@@ -11,12 +13,12 @@ def connection(args):
         name = args.name if args.name is not None else 'default'
         save_connection(conn, name=name)
 
-        print('Saved connection information as %s' % name)
+        cprint(args, 'Saved connection information as %s' % name)
     else:
         # otherwise the saved connections should be shown
         if args.name is not None:
-            print(load_connection(args.name))
+            cprint(args, load_connection(args.name))
         else:
             connections = get_connection_names()
-            print('Found %d connections:' % (len(connections)))
-            print('\n'.join(connections))
+            cprint(args, 'Found %d connections:' % (len(connections)))
+            cprint(args, '\n'.join(connections))
